@@ -63,9 +63,10 @@ def get_logger(name):
 def emit(metlog, name, values, tags=None):
     metric = Metric(name)
     metric.with_timestamp(time.time() * 1000000000)
-    if tags is not None:
-        for tag in tags:
-            metric.add_tag(tag, tags[tag])
+    if tags is None:
+        tags = {"tag": "team"}
+    for tag in tags:
+        metric.add_tag(tag, tags[tag])
     for value in values:
         metric.add_tag(value, values[value])
     metlog.info(metric)
